@@ -8,7 +8,10 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__copyright__ = '(c) 2012 Canonical Ltd.'
+__copyright__ = '''
+(c) 2012 Canonical Ltd.
+(c) 2017 - 2022 Martin Pitt <martin@piware.de>
+'''
 
 import copy
 import functools
@@ -18,6 +21,7 @@ import os
 import sys
 import time
 import types
+from pathlib import Path
 from typing import Optional, Dict, Any, List, Tuple, Sequence, KeysView
 from xml.etree import ElementTree
 
@@ -44,12 +48,13 @@ CallLogType = Tuple[int, str, Sequence[Any]]
 def load_module(name: str):
     '''Load a mock template Python module from dbusmock/templates/'''
 
-    if os.path.exists(name) and os.path.splitext(name)[1] == '.py':
-        spec = importlib.util.spec_from_file_location(os.path.splitext(os.path.basename(name))[0], name)
+    pname = Path(name)
+
+    if pname.exists() and pname.suffix == '.py':
+        spec = importlib.util.spec_from_file_location(pname.stem, name)
         assert spec
         mod = importlib.util.module_from_spec(spec)
-        with open(name, encoding="UTF-8") as f:
-            exec(f.read(), mod.__dict__, mod.__dict__)  # pylint: disable=exec-used
+        exec(pname.read_text("UTF-8"), mod.__dict__, mod.__dict__)  # pylint: disable=exec-used
         return mod
 
     return importlib.import_module('dbusmock.templates.' + name)
@@ -352,7 +357,7 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
     @dbus.service.method(MOCK_IFACE,
                          in_signature='s',
                          out_signature='')
-    def RemoveObject(self, path: str) -> None:  # pylint: disable=no-self-use
+    def RemoveObject(self, path: str) -> None:
         '''Remove a D-Bus object from the mock
 
         As with AddObject, this will *not* emit the InterfacesRemoved signal if
@@ -452,7 +457,8 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
         # mock_method(); using message_keyword with this dynamic approach fails
         # because inspect cannot handle those, so pass on interface and method
         # name as first positional arguments
-        method = lambda self, *args, **kwargs: DBusMockObject.mock_method(
+        # pylint: disable=unnecessary-lambda-assignment
+        method = lambda self, *args, **kwargs: DBusMockObject.mock_method(  # noqa: E731
             self, interface, name, in_sig, *args, **kwargs)
 
         # we cannot specify in_signature here, as that trips over a consistency
@@ -607,6 +613,25 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
         self._template = template
         self._template_parameters = parameters
 
+    def _emit_signal(self, interface: str, name: str, signature: str, sigargs: Tuple[Any, ...], details: PropsType) -> None:
+        # pylint: disable=protected-access
+        if not interface:
+            interface = self.interface
+
+        args = _convert_args(signature, sigargs)
+
+        path = details.get("path", self.path)
+        sig = dbus.lowlevel.SignalMessage(path, interface, name)
+        sig.append(*args, signature=signature)
+        dest = details.get("destination", None)
+        if dest is not None:
+            sig.set_destination(dest)
+
+        for location in self.locations:
+            conn = location[0]
+            conn.send_message(sig)
+        self.log(f'emit {path} {interface}.{name}{_format_args(args)}')
+
     @dbus.service.method(MOCK_IFACE,
                          in_signature='sssav',
                          out_signature='')
@@ -623,19 +648,28 @@ class DBusMockObject(dbus.service.Object):  # pylint: disable=too-many-instance-
         args: variant array with signal arguments; must match order and type in
               "signature"
         '''
-        # pylint: disable=protected-access
-        if not interface:
-            interface = self.interface
+        self._emit_signal(interface, name, signature, sigargs, {})
 
-        args = _convert_args(signature, sigargs)
+    @dbus.service.method(MOCK_IFACE,
+                         in_signature='sssava{sv}',
+                         out_signature='')
+    def EmitSignalDetailed(self, interface: str, name: str, signature: str, sigargs: Tuple[Any, ...], details: PropsType) -> None:
+        '''Emit a signal from the object with extra details.
 
-        fn = lambda self, *args: self.log(f'emit {self.path} {interface}.{name}{_format_args(args)}')
-        fn.__name__ = str(name)
-        dbus_fn = dbus.service.signal(interface)(fn)
-        dbus_fn._dbus_signature = signature
-        dbus_fn._dbus_args = [f'arg{i}' for i in range(1, len(args) + 1)]
-
-        dbus_fn(self, *args)
+        interface: D-Bus interface to send the signal from. For convenience you
+                   can specify '' here to add the method to the object's main
+                   interface (as specified on construction).
+        name: Name of the signal
+        signature: Signature of input arguments; for example "ias" for a signal
+                that takes an int32 and a string array as arguments; see
+                http://dbus.freedesktop.org/doc/dbus-specification.html#message-protocol-signatures
+        args: variant array with signal arguments; must match order and type in
+              "signature"
+        details: dictionary with a string key/value entries. Supported keys are:
+            "destination": for the signal destination
+            "path": for the object path to send the signal from
+        '''
+        self._emit_signal(interface, name, signature, sigargs, details)
 
     @dbus.service.method(MOCK_IFACE,
                          in_signature='',
