@@ -1,4 +1,4 @@
-'''Mock templates for common D-BUS services'''
+'''Mock templates for common D-Bus services'''
 
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
