@@ -13,7 +13,10 @@ This provides only the non-deprecated D-Bus API as of version 0.9.
 # of the license.
 
 __author__ = 'Bastien Nocera'
-__copyright__ = '(c) 2021, Red Hat Inc.'
+__copyright__ = '''
+(c) 2021, Red Hat Inc.
+(c) 2017 - 2022 Martin Pitt <martin@piware.de>
+'''
 
 import dbus
 
@@ -61,7 +64,7 @@ def load(mock, parameters):
             dbus.Dictionary({'Profile': 'balanced', 'Driver': 'dbusmock'}, signature='sv'),
             dbus.Dictionary({'Profile': 'performance', 'Driver': 'dbusmock'}, signature='sv')
         ],
-        'Actions': dbus.Array([], signature='(as)'),
+        'Actions': dbus.Array([], signature='s'),
         'ActiveProfileHolds': dbus.Array([], signature='(aa{sv})'),
     }
     mock.AddProperties(MAIN_IFACE, dbus.Dictionary(props, signature='sv'))
