@@ -7,17 +7,21 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__copyright__ = '(c) 2012 Canonical Ltd.'
+__copyright__ = '''
+(c) 2012 Canonical Ltd.
+(c) 2017 - 2022 Martin Pitt <martin@piware.de>
+'''
 
-import unittest
-import sys
-import os
-import tempfile
-import subprocess
-import shutil
-import time
 import importlib.util
+import os
+import shutil
+import subprocess
+import sys
+import tempfile
+import time
 import tracemalloc
+import unittest
+from pathlib import Path
 
 import dbus
 import dbus.mainloop.glib
@@ -55,8 +59,7 @@ class TestAPI(dbusmock.DBusTestCase):
         self.dbus_props = dbus.Interface(self.obj_test, dbus.PROPERTIES_IFACE)
 
     def assertLog(self, regex):
-        with open(self.mock_log.name, "rb") as f:
-            self.assertRegex(f.read(), regex)
+        self.assertRegex(Path(self.mock_log.name,).read_bytes(), regex)
 
     def tearDown(self):
         if self.p_mock.stdout:
@@ -335,12 +338,11 @@ assert args[2] == 5
         self.assertEqual(self.dbus_props.Get('org.freedesktop.Test.Main', 'version'), 4)
 
         # check that the Get/Set calls get logged
-        with open(self.mock_log.name, encoding="UTF-8") as f:
-            contents = f.read()
-            self.assertRegex(contents, '\n[0-9.]+ Get / org.freedesktop.Test.Main.version\n')
-            self.assertRegex(contents, '\n[0-9.]+ Get / org.freedesktop.Test.Main.connected\n')
-            self.assertRegex(contents, '\n[0-9.]+ GetAll / org.freedesktop.Test.Main\n')
-            self.assertRegex(contents, '\n[0-9.]+ Set / org.freedesktop.Test.Main.version 4\n')
+        log = Path(self.mock_log.name).read_text("UTF-8")
+        self.assertRegex(log, '\n[0-9.]+ Get / org.freedesktop.Test.Main.version\n')
+        self.assertRegex(log, '\n[0-9.]+ Get / org.freedesktop.Test.Main.connected\n')
+        self.assertRegex(log, '\n[0-9.]+ GetAll / org.freedesktop.Test.Main\n')
+        self.assertRegex(log, '\n[0-9.]+ Set / org.freedesktop.Test.Main.version 4\n')
 
         # add property to different interface
         self.dbus_mock.AddProperty('org.freedesktop.Test.Other',
@@ -463,6 +465,8 @@ assert args[2] == 5
     def test_signals(self):
         '''emitting signals'''
 
+        self.dbus_mock.AddObject('/obj1', 'org.freedesktop.Test.Sub', {}, [])
+
         def do_emit():
             self.dbus_mock.EmitSignal('', 'SigNoArgs', '', [])
             self.dbus_mock.EmitSignal('org.freedesktop.Test.Sub',
@@ -476,6 +480,10 @@ assert args[2] == 5
                                               'SigDetailed',
                                               'su', ['details', 123],
                                               {'destination': self.dbus_con.get_unique_name()})
+            self.dbus_mock.EmitSignalDetailed('',
+                                              'SigDetailedWithPath',
+                                              'su', ['details', 456],
+                                              {'path': '/obj1'})
 
         caught = []
         ml = GLib.MainLoop()
@@ -483,7 +491,7 @@ assert args[2] == 5
         def catch(*args, **kwargs):
             if kwargs['interface'].startswith('org.freedesktop.Test'):
                 caught.append((args, kwargs))
-            if len(caught) == 4:
+            if len(caught) == 5:
                 # we caught everything there is to catch, don't wait for the
                 # timeout
                 ml.quit()
@@ -538,14 +546,19 @@ assert args[2] == 5
         self.assertEqual(caught[3][1]['path'], '/')
         self.assertEqual(caught[3][1]['interface'], 'org.freedesktop.Test.Main')
 
+        self.assertEqual(caught[4][0], ('details', 456))
+        self.assertEqual(caught[4][1]['member'], 'SigDetailedWithPath')
+        self.assertEqual(caught[4][1]['path'], '/obj1')
+        self.assertEqual(caught[4][1]['interface'], 'org.freedesktop.Test.Main')
+
         # check correct logging
-        with open(self.mock_log.name, encoding="UTF-8") as f:
-            log = f.read()
+        log = Path(self.mock_log.name).read_text("UTF-8")
         self.assertRegex(log, '[0-9.]+ emit / org.freedesktop.Test.Main.SigNoArgs\n')
         self.assertRegex(log, '[0-9.]+ emit / org.freedesktop.Test.Sub.SigTwoArgs "hello" 42\n')
         self.assertRegex(log, '[0-9.]+ emit / org.freedesktop.Test.Sub.SigTypeTest -42 42')
         self.assertRegex(log, r'[0-9.]+ emit / org.freedesktop.Test.Sub.SigTypeTest -42 42 "hello" \["/a", "/b"\]\n')
         self.assertRegex(log, '[0-9.]+ emit / org.freedesktop.Test.Main.SigDetailed "details" 123\n')
+        self.assertRegex(log, '[0-9.]+ emit /obj1 org.freedesktop.Test.Main.SigDetailedWithPath "details" 456\n')
 
     def test_signals_type_mismatch(self):
         '''emitting signals with wrong arguments'''
@@ -667,6 +680,9 @@ assert args[2] == 5
         obj1 = self.dbus_con.get_object('org.freedesktop.Test', '/obj1')
         self.assertRaises(dbus.exceptions.DBusException, obj1.GetAll, '')
 
+    def test_version(self):
+        self.assertGreater(dbusmock.__version__, "0.28.0")
+
 
 class TestTemplates(dbusmock.DBusTestCase):
     '''Test template API'''
@@ -698,8 +714,8 @@ def load(mock, parameters):
 
             # ensure that we don't use/write any .pyc files, they are dangerous
             # in a world-writable directory like /tmp
-            self.assertFalse(os.path.exists(my_template.name + 'c'))
-            self.assertFalse(os.path.exists(importlib.util.cache_from_source(my_template.name)))
+            self.assertFalse(Path(my_template.name + 'c').exists())
+            self.assertFalse(Path(importlib.util.cache_from_source(my_template.name)).exists())
 
         loop = GLib.MainLoop()
         caught_signals = []
@@ -997,27 +1013,27 @@ class TestServiceAutostart(dbusmock.DBusTestCase):
 
         os.environ['XDG_DATA_DIRS'] = cls.xdg_data_dir
 
-        os.mkdir(os.path.join(cls.xdg_data_dir, 'dbus-1'))
-        system_dir = os.path.join(cls.xdg_data_dir, 'dbus-1', 'system-services')
-        session_dir = os.path.join(cls.xdg_data_dir, 'dbus-1', 'services')
-        os.mkdir(system_dir)
-        os.mkdir(session_dir)
+        dbus_dir = Path(cls.xdg_data_dir, 'dbus-1')
+        system_dir = dbus_dir / 'system-services'
+        session_dir = dbus_dir / 'services'
+        system_dir.mkdir(parents=True)
+        session_dir.mkdir()
 
-        with open(os.path.join(system_dir, 'org.TestSystem.service'), 'w', encoding='ascii') as s:
-            s.write('[D-BUS Service]\n' +
-                    'Name=org.TestSystem\n'
-                    'Exec=/usr/bin/python3 -c "import sys; from gi.repository import GLib, Gio; '
-                    '     Gio.bus_own_name(Gio.BusType.SYSTEM, \'org.TestSystem\', 0, None, None, lambda *args: sys.exit(0)); '
-                    '     GLib.MainLoop().run()"\n'
-                    'User=root')
+        (system_dir / 'org.TestSystem.service').write_text(
+            '[D-BUS Service]\n' +
+            'Name=org.TestSystem\n'
+            'Exec=/usr/bin/python3 -c "import sys; from gi.repository import GLib, Gio; '
+            '     Gio.bus_own_name(Gio.BusType.SYSTEM, \'org.TestSystem\', 0, None, None, lambda *args: sys.exit(0)); '
+            '     GLib.MainLoop().run()"\n'
+            'User=root')
 
-        with open(os.path.join(session_dir, 'org.TestSession.service'), 'w', encoding='ascii') as s:
-            s.write('[D-BUS Service]\n'
-                    'Name=org.TestSession\n'
-                    'Exec=/usr/bin/python3 -c "import sys; from gi.repository import GLib, Gio; '
-                    '     Gio.bus_own_name(Gio.BusType.SESSION, \'org.TestSession\', 0, None, None, lambda *args: sys.exit(0)); '
-                    '     GLib.MainLoop().run()"\n'
-                    'User=root')
+        (session_dir / 'org.TestSession.service').write_text(
+            '[D-BUS Service]\n'
+            'Name=org.TestSession\n'
+            'Exec=/usr/bin/python3 -c "import sys; from gi.repository import GLib, Gio; '
+            '     Gio.bus_own_name(Gio.BusType.SESSION, \'org.TestSession\', 0, None, None, lambda *args: sys.exit(0)); '
+            '     GLib.MainLoop().run()"\n'
+            'User=root')
 
         cls.start_system_bus()
         cls.start_session_bus()
@@ -1073,9 +1089,6 @@ class TestServiceAutostart(dbusmock.DBusTestCase):
 
         dbus_if.StartServiceByName('org.TestSystem', 0)
 
-    def test_version(self):
-        self.assertGreater(dbusmock.__version__, "0.28.0")
-
 
 if __name__ == '__main__':
     # avoid writing to stderr
