@@ -7,16 +7,19 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__copyright__ = '(c) 2012 Canonical Ltd.'
+__copyright__ = '''
+(c) 2012 Canonical Ltd.
+(c) 2017 - 2022 Martin Pitt <martin@piware.de>
+'''
 
 import importlib.util
-import os
-import unittest
 import shutil
-import sys
 import subprocess
+import sys
 import tempfile
 import tracemalloc
+import unittest
+from pathlib import Path
 
 import dbus
 
@@ -72,7 +75,7 @@ class TestCLI(dbusmock.DBusTestCase):
 
     def test_template_upower_explicit_path(self):
         spec = importlib.util.find_spec('dbusmock.templates.upower')
-        self.assertTrue(os.path.exists(spec.origin))
+        self.assertTrue(Path(spec.origin).exists())
         self.start_mock(['-t', spec.origin],
                         'org.freedesktop.UPower', '/org/freedesktop/UPower', True)
         self.check_upower_running()
