@@ -7,15 +7,18 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__copyright__ = '(c) 2013 Canonical Ltd.'
+__copyright__ = '''
+(c) 2013 Canonical Ltd.
+(c) 2017 - 2022 Martin Pitt <martin@piware.de>
+'''
 
-import os
 import re
 import shutil
 import subprocess
 import sys
-import unittest
 import tracemalloc
+import unittest
+from pathlib import Path
 
 import dbus
 import dbusmock
@@ -25,7 +28,7 @@ have_loginctl = shutil.which('loginctl')
 
 
 @unittest.skipUnless(have_loginctl, 'loginctl not installed')
-@unittest.skipUnless(os.path.exists('/run/systemd/system'), '/run/systemd/system does not exist')
+@unittest.skipUnless(Path('/run/systemd/system').exists(), '/run/systemd/system does not exist')
 class TestLogind(dbusmock.DBusTestCase):
     '''Test mocking logind'''
 
@@ -83,7 +86,7 @@ class TestLogind(dbusmock.DBusTestCase):
 
         out = subprocess.check_output(['loginctl', 'list-users'],
                                       universal_newlines=True)
-        self.assertRegex(out, r'(^|\n)\s*500\s+joe\s*($|\n)')
+        self.assertRegex(out, r'(^|\n)\s*500\s+joe\s*')
 
         # note, this does an actual getpwnam() in the client, so we cannot call
         # this with hardcoded user names; get from actual user in the system
